;***************************************************************************************************
;
; original FrameWork (Header/Init/Handling) by freem (ajworld.net/neogeodev/)
; all CD-Stuff removed, updated to use 'regdefs.asm' (https://wiki.neogeodev.org/index.php?title=68k_ASM_defines)
;
;***************************************************************************************************

	include "inc/regdefs.asm"		; https://wiki.neogeodev.org/index.php?title=68k_ASM_defines
	include "inc/header_68k.inc"
	include "inc/header_cart.inc"
; program RAM
	include "ram_user.inc"

;==============================================================================;
; USER
; Needs to perform actions according to the value in BIOS_USER_REQUEST.
; Must jump back to SYSTEM_RETURN at the end so the BIOS can have control.
;==============================================================================;
USER:
	move.b	d0,REG_DIPSW		; kick watchdog
	lea	$10F300,sp		; set stack pointer to BIOS_WORKRAM
	move.w	#0,REG_LSPCMODE		; Disable auto-animation, timer interrupts, set auto-anim speed to 0 frames
	move.w	#7,REG_IRQACK		; ack. all IRQs

	move.w	#$2000,sr			; Enable VBlank interrupt, go Supervisor

	; Handle user request
	clr.l	d0
	move.b	(BIOS_USER_REQUEST).l,d0
	lsl.b	#2,d0				; shift value left to get offset into table
	lea		cmds_USER_REQUEST,a0
	movea.l	(a0,d0),a0
	jsr		(a0)

;------------------------------------------------------------------------------;
; BIOS_USER_REQUEST commands
cmds_USER_REQUEST:
	dc.l	userReq_StartupInit	; Command 0 (Initialize)
	dc.l	userReq_Eyecatch	; Command 1 (Custom eyecatch)
	dc.l	userReq_Game		; Command 2 (Demo Game/Game)
	dc.l	userReq_Game		; Command 3 (Title Display)

;------------------------------------------------------------------------------;
; userReq_StartupInit
; Initialize the backup work area. This demo doesn't use it.

userReq_StartupInit:
	move.b	d0,REG_DIPSW		; kick watchdog
	jmp		BIOSF_SYSTEM_RETURN

;------------------------------------------------------------------------------;
; userReq_Eyecatch
; Only to be fully coded if your game uses its own eyecatch (value at $114 is 1).
; Otherwise, jmp to SYSTEM_RETURN.

userReq_Eyecatch:
	move.b	d0,REG_DIPSW		; kick watchdog
	jmp		BIOSF_SYSTEM_RETURN

;------------------------------------------------------------------------------;
; userReq_Game
; This is the complex one. For this demo, we're only going to treat it as a
; combination of initialization and main loop, but for a real game, you might
; want to have BIOS_USER_REQUEST commands 2 and 3 do different things.

userReq_Game:

	  jsr       BIOSF_FIX_CLEAR			; clear fix layer, add borders on sides
	  jsr	    BIOSF_LSP_1ST				; clear first sprite

          ;---------------------------------------

          move.b    d0,REG_PALBANK1
          jsr       PALETTE_SET

          ;---------------------------------------

          lea       STRING1,a0
          move.w    #5,d0
          move.w    #4,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          lea       STRING2,a0
          move.w    #11,d0
          move.w    #5,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          ;---------------------------------------


          lea       STRING10,a0
          move.w    #2,d0
          move.w    #24,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          lea       STRING11,a0
          move.w    #2,d0
          move.w    #25,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          lea       STRING12,a0
          move.w    #2,d0
          move.w    #26,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          lea       STRING13,a0
          move.w    #2,d0
          move.w    #27,d1
          move.w    #0,d2
          jsr       WRITE_STRING

          ;---------------------------------------

          move.w    #$10,CHUNKY_EFFECT
          jsr       CHUNKY_INIT

; execution continues into main loop.
;------------------------------------------------------------------------------;
; mainLoop
; The game's main loop. This is where you run the actual game part.

mainLoop:

	  move.b    BIOS_P1CHANGE,d0
	  andi.b    #$80,d0
  	  beq       noD

          add.w     #$4,CHUNKY_EFFECT
          cmp.w     #$2c,CHUNKY_EFFECT
          blt       chunky_ok
          move.w    #$10,CHUNKY_EFFECT

chunky_ok
          jsr       CHUNKY_INIT
noD

          jsr       MULTICOLOR

          jsr       WaitVBlank			  ; wait for the vblank
          jsr       CHUNKY_UPDATE                 ; then chunky

	  jmp       mainLoop

;==============================================================================;
; PLAYER_START
; Called by the BIOS if one of the Start buttons is pressed while the player
; has enough credits (or if the the time runs out on the title menu?).
; We're not using this in this demo.
;==============================================================================;
PLAYER_START:
	move.b	d0,REG_DIPSW		; kick the watchdog
	rts

;==============================================================================;
; DEMO_END
; Called by the BIOS when the Select button is pressed; ends the demo early.
;==============================================================================;
DEMO_END:
	; if necessary, store any items in the (MVS) backup RAM.
	rts

;==============================================================================;
; COIN_SOUND
; Called by the BIOS when a coin is inserted; should play a coin drop sound.
; We don't actually do anything here since this isn't meant to take coins.
;==============================================================================;
COIN_SOUND:
	; Send a sound code
	rts

;==============================================================================;
; VBlank
; VBlank interrupt, run things we want to do every frame.
;==============================================================================;
VBlank:
	; check if the BIOS wants to run its vblank
	btst	#7,BIOS_SYSTEM_MODE
	bne		.gamevbl
	; run BIOS vblank
	jmp		BIOSF_SYSTEM_INT1

	;-----------------------;
	; run the game's vblank
.gamevbl
	movem.l d0-d7/a0-a6,-(sp)	; save registers
	move.w	#4,REG_IRQACK		; acknowledge the vblank interrupt
	move.b	d0,REG_DIPSW		; kick the watchdog

	; do things in vblank

.endvbl:
	jsr		BIOSF_SYSTEM_IO			; "Call SYSTEM_IO every 1/60 second."

	move.b	#0,flag_VBlank		; clear vblank flag so waitVBlank knows to stop
	movem.l (sp)+,d0-d7/a0-a6	; restore registers
	rte

;==============================================================================;
; IRQ2
; Level 2/timer interrupt, unused here. You could use it for effects, though.
;==============================================================================;
IRQ2:
	move.w	#2,REG_IRQACK		; ack. interrupt #2 (HBlank)
	move.b	d0,REG_DIPSW		; kick watchdog
	rte

;==============================================================================;
; IRQ3
; Level 3 IRQ, unused here. Might be used for something else on CD, though.
; (More research needed)
;==============================================================================;
IRQ3:
	move.w  #1,REG_IRQACK		; acknowledge interrupt 3
	move.b	d0,REG_DIPSW		; kick watchdog
	rte

;==============================================================================;
; WaitVBlank
; Waits for VBlank to finish (via a flag cleared at the end).
;==============================================================================;
WaitVBlank:
	  move.b    #1,flag_VBlank
.waitLoop
	  tst.b     flag_VBlank
	  bne.s     .waitLoop
	  rts

;==============================================================================;

          include   "palette.asm"
          include   "fix.asm"
          include   "chunky.asm"
          include   "multicolor.asm"
